==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Keng Kalenner fonnt.",
"No events found." => "Keng Evenementer fonnt.",
"Wrong calendar" => "Falschen Kalenner",
"New Timezone:" => "Nei Zäitzone:",
"Timezone changed" => "Zäitzon geännert",
"Invalid request" => "Ongülteg Requête",
"Calendar" => "Kalenner",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"Birthday" => "Gebuertsdag",
"Business" => "Geschäftlech",
"Call" => "Uruff",
"Clients" => "Clienten",
"Deliverer" => "Liwwerant",
"Holidays" => "Vakanzen",
"Ideas" => "Ideeën",
"Journey" => "Dag",
"Jubilee" => "Jubiläum",
"Meeting" => "Meeting",
"Other" => "Aner",
"Personal" => "Perséinlech",
"Projects" => "Projeten",
"Questions" => "Froen",
"Work" => "Aarbecht",
"Does not repeat" => "Widderhëlt sech net",
"Daily" => "Deeglech",
"Weekly" => "All Woch",
"Every Weekday" => "All Wochendag",
"Bi-Weekly" => "All zweet Woch",
"Monthly" => "All Mount",
"Yearly" => "All Joer",
"never" => "ni",
"by occurrences" => "no Virkommes",
"by date" => "no Datum",
"by monthday" => "no Mount-Dag",
"by weekday" => "no Wochendag",
"Monday" => "Méindes",
"Tuesday" => "Dënschdes",
"Wednesday" => "Mëttwoch",
"Thursday" => "Donneschdes",
"Friday" => "Freides",
"Saturday" => "Samschdes",
"Sunday" => "Sonndes",
"first" => "éischt",
"second" => "Sekonn",
"third" => "Drëtt",
"fourth" => "Féiert",
"fifth" => "Fënneft",
"last" => "Läscht",
"January" => "Januar",
"February" => "Februar",
"March" => "Mäerz",
"April" => "Abrëll",
"May" => "Mee",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Dezember",
"Date" => "Datum",
"Cal." => "Cal.",
"All day" => "All Dag",
"New Calendar" => "Neien Kalenner",
"Missing fields" => "Felder déi feelen",
"Title" => "Titel",
"From Date" => "Vun Datum",
"From Time" => "Vun Zäit",
"To Date" => "Bis Datum",
"To Time" => "Bis Zäit",
"The event ends before it starts" => "D'Evenement hält op ier et ufänkt",
"There was a database fail" => "En Datebank Feeler ass opgetrueden",
"Week" => "Woch",
"Month" => "Mount",
"List" => "Lescht",
"Today" => "Haut",
"Calendars" => "Kalenneren",
"There was a fail, while parsing the file." => "Feeler beim lueden vum Fichier.",
"Choose active calendars" => "Wiel aktiv Kalenneren aus",
"Your calendars" => "Deng Kalenneren",
"CalDav Link" => "CalDav Link",
"Shared calendars" => "Gedeelte Kalenneren",
"No shared calendars" => "Keng gedeelten Kalenneren",
"Download" => "Eroflueden",
"Edit" => "Editéieren",
"Delete" => "Läschen",
"New calendar" => "Neien Kalenner",
"Edit calendar" => "Kalenner editéieren",
"Displayname" => "Numm",
"Active" => "Aktiv",
"Calendar color" => "Fuerf vum Kalenner",
"Save" => "Späicheren",
"Submit" => "Fortschécken",
"Cancel" => "Ofbriechen",
"Edit an event" => "Evenement editéieren",
"Export" => "Export",
"Title of the Event" => "Titel vum Evenement",
"Category" => "Kategorie",
"All Day Event" => "Ganz-Dag Evenement",
"From" => "Vun",
"To" => "Fir",
"Advanced options" => "Avancéiert Optiounen",
"Location" => "Uert",
"Location of the Event" => "Uert vum Evenement",
"Description" => "Beschreiwung",
"Description of the Event" => "Beschreiwung vum Evenement",
"Repeat" => "Widderhuelen",
"Advanced" => "Erweidert",
"Select weekdays" => "Wochendeeg auswielen",
"Select days" => "Deeg auswielen",
"Select months" => "Méint auswielen",
"Select weeks" => "Wochen auswielen",
"Interval" => "Intervall",
"End" => "Enn",
"occurrences" => "Virkommes",
"Import a calendar file" => "E Kalenner Fichier importéieren",
"Please choose the calendar" => "Wiel den Kalenner aus",
"create a new calendar" => "E neie Kalenner uleeën",
"Name of new calendar" => "Numm vum neie Kalenner",
"Import" => "Import",
"Importing calendar" => "Importéiert Kalenner",
"Calendar imported successfully" => "Kalenner erfollegräich importéiert",
"Close Dialog" => "Dialog zoumaachen",
"Create a new event" => "En Evenement maachen",
"Select category" => "Kategorie auswielen",
"Timezone" => "Zäitzon",
"Timeformat" => "Zäit Format",
"24h" => "24h",
"12h" => "12h",
"Calendar CalDAV syncing address:" => "CalDAV Kalenner Synchronisatioun's Adress:"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Keng Kalenner fonnt.",
"No events found." => "Keng Evenementer fonnt.",
"Wrong calendar" => "Falschen Kalenner",
"New Timezone:" => "Nei Zäitzone:",
"Timezone changed" => "Zäitzon geännert",
"Invalid request" => "Ongülteg Requête",
"Calendar" => "Kalenner",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"Birthday" => "Gebuertsdag",
"Business" => "Geschäftlech",
"Call" => "Uruff",
"Clients" => "Clienten",
"Deliverer" => "Liwwerant",
"Holidays" => "Vakanzen",
"Ideas" => "Ideeën",
"Journey" => "Dag",
"Jubilee" => "Jubiläum",
"Meeting" => "Meeting",
"Other" => "Aner",
"Personal" => "Perséinlech",
"Projects" => "Projeten",
"Questions" => "Froen",
"Work" => "Aarbecht",
"unnamed" => "ouni Numm",
"New Calendar" => "Neien Kalenner",
"Does not repeat" => "Widderhëlt sech net",
"Daily" => "Deeglech",
"Weekly" => "All Woch",
"Every Weekday" => "All Wochendag",
"Bi-Weekly" => "All zweet Woch",
"Monthly" => "All Mount",
"Yearly" => "All Joer",
"never" => "ni",
"by occurrences" => "no Virkommes",
"by date" => "no Datum",
"by monthday" => "no Mount-Dag",
"by weekday" => "no Wochendag",
"Monday" => "Méindes",
"Tuesday" => "Dënschdes",
"Wednesday" => "Mëttwoch",
"Thursday" => "Donneschdes",
"Friday" => "Freides",
"Saturday" => "Samschdes",
"Sunday" => "Sonndes",
"events week of month" => "Events Woch vum mount",
"first" => "éischt",
"second" => "Sekonn",
"third" => "Drëtt",
"fourth" => "Féiert",
"fifth" => "Fënneft",
"last" => "Läscht",
"January" => "Januar",
"February" => "Februar",
"March" => "Mäerz",
"April" => "Abrëll",
"May" => "Mee",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Dezember",
"by events date" => "no Events Datum",
"by yearday(s)" => "no Joerdag/deeg",
"by weeknumber(s)" => "no Wochenummer(en)",
"by day and month" => "no Dag a Mount",
"Date" => "Datum",
"Cal." => "Cal.",
"All day" => "All Dag",
"Missing fields" => "Felder déi feelen",
"Title" => "Titel",
"From Date" => "Vun Datum",
"From Time" => "Vun Zäit",
"To Date" => "Bis Datum",
"To Time" => "Bis Zäit",
"The event ends before it starts" => "D'Evenement hält op ier et ufänkt",
"There was a database fail" => "En Datebank Feeler ass opgetrueden",
"Week" => "Woch",
"Month" => "Mount",
"List" => "Lescht",
"Today" => "Haut",
"Your calendars" => "Deng Kalenneren",
"CalDav Link" => "CalDav Link",
"Share Calendar" => "Kalenner deelen",
"Download" => "Eroflueden",
"Edit" => "Editéieren",
"Delete" => "Läschen",
"shared with you by" => "vun dir geshared mat",
"New calendar" => "Neien Kalenner",
"Edit calendar" => "Kalenner editéieren",
"Displayname" => "Numm",
"Active" => "Aktiv",
"Calendar color" => "Fuerf vum Kalenner",
"Save" => "Späicheren",
"Submit" => "Fortschécken",
"Cancel" => "Ofbriechen",
"Edit an event" => "Evenement editéieren",
"Export" => "Export",
"Eventinfo" => "Event Info",
"Repeating" => "Widderhëlt sech",
"Alarm" => "Alarm",
"Title of the Event" => "Titel vum Evenement",
"Category" => "Kategorie",
"All Day Event" => "Ganz-Dag Evenement",
"From" => "Vun",
"To" => "Fir",
"Advanced options" => "Avancéiert Optiounen",
"Location" => "Uert",
"Location of the Event" => "Uert vum Evenement",
"Description" => "Beschreiwung",
"Description of the Event" => "Beschreiwung vum Evenement",
"Repeat" => "Widderhuelen",
"Advanced" => "Erweidert",
"Select weekdays" => "Wochendeeg auswielen",
"Select days" => "Deeg auswielen",
"and the events day of year." => "an den Events Dag vum Joer.",
"and the events day of month." => "an den Events Dag vum Mount.",
"Select months" => "Méint auswielen",
"Select weeks" => "Wochen auswielen",
"and the events week of year." => "an den d'Events Woch vum Joer.",
"Interval" => "Intervall",
"End" => "Enn",
"occurrences" => "Virkommes",
"create a new calendar" => "E neie Kalenner uleeën",
"Import a calendar file" => "E Kalenner Fichier importéieren",
"Name of new calendar" => "Numm vum neie Kalenner",
"Import" => "Import",
"Close Dialog" => "Dialog zoumaachen",
"Create a new event" => "En Evenement maachen",
"Timezone" => "Zäitzon",
"24h" => "24h",
"12h" => "12h"
);
